@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2009 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  *
  * Licensed under the GNU General Public License Version 2
@@ -39,17 +39,17 @@
 
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
+#include <gconf/gconf-client.h>
 
-#include <libhal-gmanager.h>
+#include <hal-manager.h>
 
 #include "gpm-ac-adapter.h"
 #include "gpm-button.h"
 #include "gpm-backlight.h"
 #include "gpm-brightness.h"
-#include "gpm-conf.h"
 #include "gpm-control.h"
 #include "gpm-common.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-feedback-widget.h"
 #include "gpm-dpms.h"
 #include "gpm-idle.h"
@@ -58,8 +58,6 @@
 #include "gpm-stock-icons.h"
 #include "gpm-prefs-server.h"
 
-#define DIM_INTERVAL		10 /* ms */
-
 #define GPM_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BACKLIGHT, GpmBacklightPrivate))
 
 struct GpmBacklightPrivate
@@ -67,7 +65,7 @@ struct GpmBacklightPrivate
 	GpmAcAdapter		*ac_adapter;
 	GpmBrightness		*brightness;
 	GpmButton		*button;
-	GpmConf			*conf;
+	GConfClient		*conf;
 	GpmFeedback		*feedback;
 	GpmControl		*control;
 	GpmDpms			*dpms;
@@ -90,7 +88,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0 };
+static guint signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmBacklight, gpm_backlight, G_TYPE_OBJECT)
 
@@ -102,9 +100,8 @@ GQuark
 gpm_backlight_error_quark (void)
 {
 	static GQuark quark = 0;
-	if (!quark) {
+	if (!quark)
 		quark = g_quark_from_static_string ("gpm_backlight_error");
-	}
 	return quark;
 }
 
@@ -117,20 +114,19 @@ gpm_backlight_error_quark (void)
 static void
 gpm_backlight_sync_policy (GpmBacklight *backlight)
 {
-	GError  *error;
+	GError *error;
 	gboolean res;
-	guint    timeout = 0;
-	guint    standby = 0;
-	guint    suspend = 0;
-	guint    off = 0;
-	gchar   *dpms_method;
+	guint timeout = 0;
+	guint standby = 0;
+	guint suspend = 0;
+	guint off = 0;
+	gchar *dpms_method;
 	GpmDpmsMethod method;
 	gboolean on_ac;
 
 	/* no point processing if we can't do the dpms action */
-	if (backlight->priv->can_dpms == FALSE) {
+	if (!backlight->priv->can_dpms)
 		return;
-	}
 
 	/* get the ac state */
 	on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
@@ -138,11 +134,11 @@ gpm_backlight_sync_policy (GpmBacklight *backlight)
 	error = NULL;
 
 	if (on_ac) {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC, &timeout);
-		gpm_conf_get_string (backlight->priv->conf, GPM_CONF_BACKLIGHT_DPMS_METHOD_AC, &dpms_method);
+		timeout = gconf_client_get_int (backlight->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC, NULL);
+		dpms_method = gconf_client_get_string (backlight->priv->conf, GPM_CONF_BACKLIGHT_DPMS_METHOD_AC, NULL);
 	} else {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT, &timeout);
-		gpm_conf_get_string (backlight->priv->conf, GPM_CONF_BACKLIGHT_DPMS_METHOD_BATT, &dpms_method);
+		timeout = gconf_client_get_int (backlight->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT, NULL);
+		dpms_method = gconf_client_get_string (backlight->priv->conf, GPM_CONF_BACKLIGHT_DPMS_METHOD_BATT, NULL);
 	}
 
 	/* convert the string types to standard types */
@@ -151,18 +147,18 @@ gpm_backlight_sync_policy (GpmBacklight *backlight)
 
 	/* check if method is valid */
 	if (method == GPM_DPMS_METHOD_UNKNOWN) {
-		gpm_warning ("BACKLIGHT method unknown. Possible schema problem!");
+		egg_warning ("BACKLIGHT method unknown. Possible schema problem!");
 		return;
 	}
 
 	/* choose a sensible default */
 	if (method == GPM_DPMS_METHOD_DEFAULT) {
-		gpm_debug ("choosing sensible default");
+		egg_debug ("choosing sensible default");
 		if (backlight->priv->is_laptop) {
-			gpm_debug ("laptop, so use GPM_DPMS_METHOD_OFF");
+			egg_debug ("laptop, so use GPM_DPMS_METHOD_OFF");
 			method = GPM_DPMS_METHOD_OFF;
 		} else {
-			gpm_debug ("not laptop, so use GPM_BACKLIGHT_METHOD_STAGGER");
+			egg_debug ("not laptop, so use GPM_BACKLIGHT_METHOD_STAGGER");
 			method = GPM_DPMS_METHOD_STAGGER;
 		}
 	}
@@ -173,30 +169,30 @@ gpm_backlight_sync_policy (GpmBacklight *backlight)
 		/* suspend after one timeout, turn off after another */
 		standby = timeout;
 		suspend = timeout;
-		off     = timeout * 2;
+		off = timeout * 2;
 	} else if (method == GPM_DPMS_METHOD_STANDBY) {
 		standby = timeout;
 		suspend = 0;
-		off     = 0;
+		off = 0;
 	} else if (method == GPM_DPMS_METHOD_SUSPEND) {
 		standby = 0;
 		suspend = timeout;
-		off     = 0;
+		off = 0;
 	} else if (method == GPM_DPMS_METHOD_OFF) {
 		standby = 0;
 		suspend = 0;
-		off     = timeout;
+		off = timeout;
 	} else {
 		/* wtf? */
-		gpm_warning ("unknown backlight mode!");
+		egg_warning ("unknown backlight mode!");
 	}
 
-	gpm_debug ("BACKLIGHT parameters %d %d %d, method '%i'", standby, suspend, off, method);
+	egg_debug ("BACKLIGHT parameters %d %d %d, method '%i'", standby, suspend, off, method);
 
 	error = NULL;
 	res = gpm_dpms_set_enabled (backlight->priv->dpms, TRUE, &error);
 	if (error) {
-		gpm_warning ("Unable to enable BACKLIGHT: %s", error->message);
+		egg_warning ("Unable to enable BACKLIGHT: %s", error->message);
 		g_error_free (error);
 		return;
 	}
@@ -204,7 +200,7 @@ gpm_backlight_sync_policy (GpmBacklight *backlight)
 	error = NULL;
 	res = gpm_dpms_set_timeouts (backlight->priv->dpms, standby, suspend, off, &error);
 	if (error) {
-		gpm_warning ("Unable to get BACKLIGHT timeouts: %s", error->message);
+		egg_warning ("Unable to get BACKLIGHT timeouts: %s", error->message);
 		g_error_free (error);
 		return;
 	}
@@ -212,9 +208,7 @@ gpm_backlight_sync_policy (GpmBacklight *backlight)
 
 /* dbus methods shouldn't use enumerated types, but should use textual descriptors */
 gboolean
-gpm_backlight_set_mode (GpmBacklight *backlight,
-			const gchar  *mode_str,
-			GError      **error)
+gpm_backlight_set_mode (GpmBacklight *backlight, const gchar *mode_str, GError **error)
 {
 	gboolean ret;
 	GpmDpmsMode mode;
@@ -257,9 +251,8 @@ gpm_backlight_get_mode (GpmBacklight *backlight,
 	}
 
 	ret = gpm_dpms_get_mode_enum (backlight->priv->dpms, &mode, error);
-	if (ret) {
+	if (ret)
 		*mode_str = g_strdup (gpm_dpms_mode_to_string (mode));
-	}
 	return ret;
 }
 
@@ -327,7 +320,7 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 	}
 	/* we emit a signal for the brightness applet */
 	if (ret && hw_changed) {
-		gpm_debug ("emitting brightness-changed : %i", percentage);
+		egg_debug ("emitting brightness-changed : %i", percentage);
 		g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 	}
 	return ret;
@@ -364,29 +357,29 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	guint old_value;
 
 	if (backlight->priv->can_dim == FALSE) {
-		gpm_warning ("no dimming hardware");
+		egg_warning ("no dimming hardware");
 		return FALSE;
 	}
 
-	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_ENABLE, &do_laptop_lcd);
+	do_laptop_lcd = gconf_client_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_ENABLE, NULL);
 	if (do_laptop_lcd == FALSE) {
-		gpm_warning ("policy is no dimming");
+		egg_warning ("policy is no dimming");
 		return FALSE;
 	}
 
 	/* get the last set brightness */
 	brightness = backlight->priv->master_percentage / 100.0f;
-	gpm_debug ("1. main brightness %f", brightness);
+	egg_debug ("1. main brightness %f", brightness);
 
 	/* get AC status */
 	on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
 
 	/* reduce if on battery power if we should */
-	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_BATTERY_REDUCE, &battery_reduce);
+	battery_reduce = gconf_client_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_BATTERY_REDUCE, NULL);
 	if (on_ac == FALSE && battery_reduce) {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BACKLIGHT_BRIGHTNESS_DIM_BATT, &value);
+		value = gconf_client_get_int (backlight->priv->conf, GPM_CONF_BACKLIGHT_BRIGHTNESS_DIM_BATT, NULL);
 		if (value > 100) {
-			gpm_warning ("cannot use battery brightness value %i, correcting to 50", value);
+			egg_warning ("cannot use battery brightness value %i, correcting to 50", value);
 			value = 50;
 		}
 		scale = (100 - value) / 100.0f;
@@ -394,18 +387,17 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	} else {
 		scale = 1.0f;
 	}
-	gpm_debug ("2. battery scale %f, brightness %f", scale, brightness);
+	egg_debug ("2. battery scale %f, brightness %f", scale, brightness);
 
 	/* reduce if system is momentarily idle */
-	if (on_ac) {
-		gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_AC, &enable_action);
-	} else {
-		gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_BATT, &enable_action);
-	}
-	if (enable_action && backlight->priv->system_is_idle == TRUE) {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_BRIGHTNESS, &value);
+	if (on_ac)
+		enable_action = gconf_client_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_AC, NULL);
+	else
+		enable_action = gconf_client_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_BATT, NULL);
+	if (enable_action && backlight->priv->system_is_idle) {
+		value = gconf_client_get_int (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_BRIGHTNESS, NULL);
 		if (value > 100) {
-			gpm_warning ("cannot use idle brightness value %i, correcting to 50", value);
+			egg_warning ("cannot use idle brightness value %i, correcting to 50", value);
 			value = 50;
 		}
 		scale = value / 100.0f;
@@ -413,14 +405,14 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	} else {
 		scale = 1.0f;
 	}
-	gpm_debug ("3. idle scale %f, brightness %f", scale, brightness);
+	egg_debug ("3. idle scale %f, brightness %f", scale, brightness);
 
 	/* reduce if ambient is low */
-	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_AMBIENT_ENABLE, &enable_action);
-	if (backlight->priv->can_sense && enable_action == TRUE) {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AMBIENT_SCALE, &value);
+	enable_action = gconf_client_get_bool (backlight->priv->conf, GPM_CONF_AMBIENT_ENABLE, NULL);
+	if (backlight->priv->can_sense && enable_action) {
+		value = gconf_client_get_int (backlight->priv->conf, GPM_CONF_AMBIENT_SCALE, NULL);
 		scale = backlight->priv->ambient_sensor_value * (value / 100.0f);
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AMBIENT_FACTOR, &value);
+		value = gconf_client_get_int (backlight->priv->conf, GPM_CONF_AMBIENT_FACTOR, NULL);
 		scale = gpm_common_sum_scale (brightness, scale, value / 100.0f);
 		if (scale > 1.0f) {
 			scale = 1.0f;
@@ -433,7 +425,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	} else {
 		scale = 1.0f;
 	}
-	gpm_debug ("4. ambient scale %f, brightness %f", scale, brightness);
+	egg_debug ("4. ambient scale %f, brightness %f", scale, brightness);
 
 	/* convert to percentage */
 	value = (guint) ((brightness * 100.0f) + 0.5);
@@ -441,66 +433,67 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	/* only do stuff if the brightness is different */
 	gpm_brightness_get (backlight->priv->brightness, &old_value);
 	if (old_value == value) {
-		gpm_debug ("values are the same, no action");
+		egg_debug ("values are the same, no action");
 		return FALSE;
 	}
 
 	/* only show dialog if interactive */
-	if (interactive) {
+	if (interactive)
 		gpm_feedback_display_value (backlight->priv->feedback, (float) brightness);
-	}
 
 	ret = gpm_brightness_set (backlight->priv->brightness, value, &hw_changed);
 	/* we emit a signal for the brightness applet */
 	if (ret && hw_changed) {
-		gpm_debug ("emitting brightness-changed : %i", value);
+		egg_debug ("emitting brightness-changed : %i", value);
 		g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, value);
 	}
 	return TRUE;
 }
 
 /**
- * conf_key_changed_cb:
+ * gpm_conf_gconf_key_changed_cb:
  *
  * We might have to do things when the gconf keys change; do them here.
  **/
 static void
-conf_key_changed_cb (GpmConf *conf, const gchar *key, GpmBacklight *backlight)
+gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmBacklight *backlight)
 {
+	GConfValue *value;
 	gboolean on_ac;
+
+	value = gconf_entry_get_value (entry);
+	if (value == NULL)
+		return;
+
 	on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
 
-	if (on_ac && strcmp (key, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC) == 0) {
-		gpm_conf_get_uint (backlight->priv->conf,
-				   GPM_CONF_BACKLIGHT_BRIGHTNESS_AC,
-				   &backlight->priv->master_percentage);
+	if (on_ac && strcmp (entry->key, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC) == 0) {
+		backlight->priv->master_percentage = gconf_value_get_int (value);
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
-	} else if (!on_ac && strcmp (key, GPM_CONF_BACKLIGHT_BRIGHTNESS_DIM_BATT) == 0) {
-		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
-	}
-
-	else if (strcmp (key, GPM_CONF_BACKLIGHT_IDLE_DIM_AC) == 0 ||
-	         strcmp (key, GPM_CONF_AMBIENT_ENABLE) == 0 ||
-	         strcmp (key, GPM_CONF_AMBIENT_FACTOR) == 0 ||
-	         strcmp (key, GPM_CONF_AMBIENT_SCALE) == 0 ||
-	         strcmp (key, GPM_CONF_BACKLIGHT_ENABLE) == 0 ||
-	         strcmp (key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
-	         strcmp (key, GPM_CONF_BACKLIGHT_BATTERY_REDUCE) == 0 ||
-	         strcmp (key, GPM_CONF_BACKLIGHT_IDLE_BRIGHTNESS) == 0) {
+	} else if (!on_ac && strcmp (entry->key, GPM_CONF_BACKLIGHT_BRIGHTNESS_DIM_BATT) == 0) {
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
-	} else if (strcmp (key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
-	           strcmp (key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC) == 0 ||
-	           strcmp (key, GPM_CONF_BACKLIGHT_DPMS_METHOD_AC) == 0 ||
-	           strcmp (key, GPM_CONF_BACKLIGHT_DPMS_METHOD_BATT) == 0) {
+	} else if (strcmp (entry->key, GPM_CONF_BACKLIGHT_IDLE_DIM_AC) == 0 ||
+	         strcmp (entry->key, GPM_CONF_AMBIENT_ENABLE) == 0 ||
+	         strcmp (entry->key, GPM_CONF_AMBIENT_FACTOR) == 0 ||
+	         strcmp (entry->key, GPM_CONF_AMBIENT_SCALE) == 0 ||
+	         strcmp (entry->key, GPM_CONF_BACKLIGHT_ENABLE) == 0 ||
+	         strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
+	         strcmp (entry->key, GPM_CONF_BACKLIGHT_BATTERY_REDUCE) == 0 ||
+	         strcmp (entry->key, GPM_CONF_BACKLIGHT_IDLE_BRIGHTNESS) == 0) {
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
+
+	} else if (strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
+	           strcmp (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC) == 0 ||
+	           strcmp (entry->key, GPM_CONF_BACKLIGHT_DPMS_METHOD_AC) == 0 ||
+	           strcmp (entry->key, GPM_CONF_BACKLIGHT_DPMS_METHOD_BATT) == 0) {
 		gpm_backlight_sync_policy (backlight);
-	} else if (strcmp (key, GPM_CONF_BACKLIGHT_IDLE_DIM_TIME) == 0) {
-		gpm_conf_get_uint (backlight->priv->conf,
-				   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
-				   &backlight->priv->idle_dim_timeout);
+	} else if (strcmp (entry->key, GPM_CONF_BACKLIGHT_IDLE_DIM_TIME) == 0) {
+		backlight->priv->idle_dim_timeout = gconf_value_get_int (value);
+		gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 	} else {
-		gpm_debug ("unknown key %s", key);
+		egg_debug ("unknown key %s", entry->key);
 	}
 }
 
@@ -513,9 +506,7 @@ conf_key_changed_cb (GpmConf *conf, const gchar *key, GpmBacklight *backlight)
  * Does the actions when the ac power source is inserted/removed.
  **/
 static void
-ac_adapter_changed_cb (GpmAcAdapter     *ac_adapter,
-		       gboolean		 on_ac,
-		       GpmBacklight     *backlight)
+ac_adapter_changed_cb (GpmAcAdapter *ac_adapter, gboolean on_ac, GpmBacklight *backlight)
 {
 	gpm_backlight_brightness_evaluate_and_set (backlight, TRUE);
 }
@@ -533,7 +524,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 	guint percentage;
 	gboolean ret;
 	gboolean hw_changed;
-	gpm_debug ("Button press event type=%s", type);
+	egg_debug ("Button press event type=%s", type);
 
 	if (strcmp (type, GPM_BUTTON_BRIGHT_UP) == 0) {
 		/* go up one step */
@@ -548,7 +539,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		}
 		/* we emit a signal for the brightness applet */
 		if (ret && hw_changed) {
-			gpm_debug ("emitting brightness-changed : %i", percentage);
+			egg_debug ("emitting brightness-changed : %i", percentage);
 			g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 		}
 	} else if (strcmp (type, GPM_BUTTON_BRIGHT_DOWN) == 0) {
@@ -564,7 +555,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		}
 		/* we emit a signal for the brightness applet */
 		if (ret && hw_changed) {
-			gpm_debug ("emitting brightness-changed : %i", percentage);
+			egg_debug ("emitting brightness-changed : %i", percentage);
 			g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 		}
 	} else if (strcmp (type, GPM_BUTTON_LID_OPEN) == 0) {
@@ -584,7 +575,7 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 
 	/* no point continuing */
 	if (backlight->priv->system_is_idle == is_idle) {
-		gpm_debug ("state not changed");
+		egg_debug ("state not changed");
 		return FALSE;
 	}
 
@@ -593,38 +584,32 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 	g_timer_reset (backlight->priv->idle_timer);
 
 	if (is_idle == FALSE) {
-		gpm_debug ("we have just been idle for %lfs", elapsed);
+		egg_debug ("we have just been idle for %lfs", elapsed);
 
 		/* The user immediatly undimmed the screen!
 		 * We should double the timeout to avoid this happening again */
 		if (elapsed < 10) {
 			/* double the event time */
 			backlight->priv->idle_dim_timeout *= 2.0;
-			gpm_conf_set_uint (backlight->priv->conf,
-					   GPM_CONF_GNOME_SS_PM_DELAY,
-					   backlight->priv->idle_dim_timeout);
-			gpm_debug ("increasing idle dim time to %is",
-				   backlight->priv->idle_dim_timeout);
+			egg_debug ("increasing idle dim time to %is", backlight->priv->idle_dim_timeout);
+			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 		}
 
 		/* We reset the dimming after 2 minutes of idle,
 		 * as the user will have changed tasks */
 		if (elapsed > 2*60) {
 			/* reset back to our default dimming */
-			gpm_conf_get_uint (backlight->priv->conf,
-					   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
-					   &backlight->priv->idle_dim_timeout);
-			gpm_conf_set_uint (backlight->priv->conf,
-					   GPM_CONF_GNOME_SS_PM_DELAY,
-					   backlight->priv->idle_dim_timeout);
-			gpm_debug ("resetting idle dim time to %is",
-				   backlight->priv->idle_dim_timeout);
+			backlight->priv->idle_dim_timeout =
+				gconf_client_get_int (backlight->priv->conf,
+					   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME, NULL);
+			egg_debug ("resetting idle dim time to %is", backlight->priv->idle_dim_timeout);
+			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 		}
 	} else {
-		gpm_debug ("we were active for %lfs", elapsed);
+		egg_debug ("we were active for %lfs", elapsed);
 	}
 
-	gpm_debug ("changing powersave idle status to %i", is_idle);
+	egg_debug ("changing powersave idle status to %i", is_idle);
 	backlight->priv->system_is_idle = is_idle;
 	return TRUE;
 }
@@ -632,25 +617,22 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 /**
  * idle_changed_cb:
  * @idle: The idle class instance
- * @mode: The idle mode, e.g. GPM_IDLE_MODE_SESSION
+ * @mode: The idle mode, e.g. GPM_IDLE_MODE_BLANK
  * @manager: This class instance
  *
  * This callback is called when gnome-screensaver detects that the idle state
- * has changed. GPM_IDLE_MODE_SESSION is when the session has become inactive,
- * and GPM_IDLE_MODE_SYSTEM is where the session has become inactive, AND the
+ * has changed. GPM_IDLE_MODE_BLANK is when the session has become inactive,
+ * and GPM_IDLE_MODE_SLEEP is where the session has become inactive, AND the
  * session timeout has elapsed for the idle action.
  **/
 static void
-idle_changed_cb (GpmIdle      *idle,
-		 GpmIdleMode   mode,
-		 GpmBacklight *backlight)
+idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 {
 	GError *error;
 
 	/* don't dim or undim the screen when the lid is closed */
-	if (gpm_button_is_lid_closed (backlight->priv->button)) {
+	if (gpm_button_is_lid_closed (backlight->priv->button))
 		return;
-	}
 
 	if (mode == GPM_IDLE_MODE_NORMAL) {
 		/* deactivate display power management */
@@ -658,7 +640,7 @@ idle_changed_cb (GpmIdle      *idle,
 			error = NULL;
 			gpm_dpms_set_active (backlight->priv->dpms, FALSE, &error);
 			if (error) {
-				gpm_debug ("Unable to set DPMS not active: %s", error->message);
+				egg_debug ("Unable to set DPMS not active: %s", error->message);
 				g_error_free (error);
 			}
 		}
@@ -670,13 +652,13 @@ idle_changed_cb (GpmIdle      *idle,
 		/* sync timeouts */
 		gpm_backlight_sync_policy (backlight);
 
-	} else if (mode == GPM_IDLE_MODE_SESSION) {
+	} else if (mode == GPM_IDLE_MODE_BLANK) {
 		/* activate display power management */
 		if (backlight->priv->can_dpms) {
 			error = NULL;
 			gpm_dpms_set_active (backlight->priv->dpms, TRUE, &error);
 			if (error) {
-				gpm_debug ("Unable to set DPMS active: %s", error->message);
+				egg_debug ("Unable to set DPMS active: %s", error->message);
 				g_error_free (error);
 			}
 		}
@@ -688,7 +670,7 @@ idle_changed_cb (GpmIdle      *idle,
 		/* sync timeouts */
 		gpm_backlight_sync_policy (backlight);
 
-	} else if (mode == GPM_IDLE_MODE_POWERSAVE) {
+	} else if (mode == GPM_IDLE_MODE_DIM) {
 
 		/* sync lcd brightness */
 		gpm_backlight_notify_system_idle_changed (backlight, TRUE);
@@ -704,11 +686,9 @@ idle_changed_cb (GpmIdle      *idle,
  * What happens when the DPMS mode is changed.
  **/
 static void
-mode_changed_cb (GpmDpms      *dpms,
-		 GpmDpmsMode   mode,
-		 GpmBacklight *backlight)
+mode_changed_cb (GpmDpms *dpms, GpmDpmsMode mode, GpmBacklight *backlight)
 {
-	gpm_debug ("emitting mode-changed : %s", gpm_dpms_mode_to_string (mode));
+	egg_debug ("emitting mode-changed : %s", gpm_dpms_mode_to_string (mode));
 	g_signal_emit (backlight, signals [MODE_CHANGED], 0, gpm_dpms_mode_to_string (mode));
 }
 
@@ -724,14 +704,14 @@ static void
 brightness_changed_cb (GpmBrightness *brightness, guint percentage, GpmBacklight *backlight)
 {
 	/* display the widget when something else changed the backlight */
-	gpm_debug ("Need to display backlight feedback value %i", percentage);
+	egg_debug ("Need to display backlight feedback value %i", percentage);
 	gpm_feedback_display_value (backlight->priv->feedback, (float) percentage / 100.0f);
 
 	/* save the new percentage */
 	backlight->priv->master_percentage = percentage;
 
 	/* we emit a signal for the brightness applet */
-	gpm_debug ("emitting brightness-changed : %i", percentage);
+	egg_debug ("emitting brightness-changed : %i", percentage);
 	g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 }
 
@@ -744,11 +724,9 @@ brightness_changed_cb (GpmBrightness *brightness, guint percentage, GpmBacklight
  * This callback is called when the brightness value changes.
  **/
 static void
-sensor_changed_cb (GpmLightSensor *sensor,
-		   guint           percentage,
-		   GpmBacklight   *backlight)
+sensor_changed_cb (GpmLightSensor *sensor, guint percentage, GpmBacklight *backlight)
 {
-	gpm_debug ("sensor changed! %i", percentage);
+	egg_debug ("sensor changed! %i", percentage);
 	backlight->priv->ambient_sensor_value = percentage / 100.0f;
 	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 }
@@ -761,9 +739,7 @@ sensor_changed_cb (GpmLightSensor *sensor,
  * We have to update the caches on resume
  **/
 static void
-control_resume_cb (GpmControl      *control,
-		   GpmControlAction action,
-		   GpmBacklight    *backlight)
+control_resume_cb (GpmControl *control, GpmControlAction action, GpmBacklight *backlight)
 {
 	gpm_backlight_sync_policy (backlight);
 }
@@ -781,33 +757,17 @@ gpm_backlight_finalize (GObject *object)
 
 	g_timer_destroy (backlight->priv->idle_timer);
 
-	if (backlight->priv->light_sensor != NULL) {
-		g_object_unref (backlight->priv->light_sensor);
-	}
-	if (backlight->priv->feedback != NULL) {
-		g_object_unref (backlight->priv->feedback);
-	}
-	if (backlight->priv->dpms != NULL) {
+	if (backlight->priv->dpms != NULL)
 		g_object_unref (backlight->priv->dpms);
-	}
-	if (backlight->priv->control != NULL) {
+	if (backlight->priv->control != NULL)
 		g_object_unref (backlight->priv->control);
-	}
-	if (backlight->priv->conf != NULL) {
-		g_object_unref (backlight->priv->conf);
-	}
-	if (backlight->priv->ac_adapter != NULL) {
-		g_object_unref (backlight->priv->ac_adapter);
-	}
-	if (backlight->priv->button != NULL) {
-		g_object_unref (backlight->priv->button);
-	}
-	if (backlight->priv->idle != NULL) {
-		g_object_unref (backlight->priv->idle);
-	}
-	if (backlight->priv->brightness != NULL) {
-		g_object_unref (backlight->priv->brightness);
-	}
+	g_object_unref (backlight->priv->light_sensor);
+	g_object_unref (backlight->priv->feedback);
+	g_object_unref (backlight->priv->conf);
+	g_object_unref (backlight->priv->ac_adapter);
+	g_object_unref (backlight->priv->button);
+	g_object_unref (backlight->priv->idle);
+	g_object_unref (backlight->priv->brightness);
 
 	g_return_if_fail (backlight->priv != NULL);
 	G_OBJECT_CLASS (gpm_backlight_parent_class)->finalize (object);
@@ -853,7 +813,7 @@ gpm_backlight_class_init (GpmBacklightClass *klass)
 static void
 gpm_backlight_init (GpmBacklight *backlight)
 {
-	HalGManager *hal_manager;
+	HalManager *hal_manager;
 	guint value;
 	GpmPrefsServer *prefs_server;
 
@@ -878,41 +838,32 @@ gpm_backlight_init (GpmBacklight *backlight)
 	backlight->priv->can_sense = gpm_light_sensor_has_hw (backlight->priv->light_sensor);
 
 	/* we use hal to see if we are a laptop */
-	hal_manager = hal_gmanager_new ();
-	backlight->priv->is_laptop = hal_gmanager_is_laptop (hal_manager);
+	hal_manager = hal_manager_new ();
+	backlight->priv->is_laptop = hal_manager_is_laptop (hal_manager);
 	g_object_unref (hal_manager);
 
 	/* expose ui in prefs program */
 	prefs_server = gpm_prefs_server_new ();
-	if (backlight->priv->is_laptop) {
+	if (backlight->priv->is_laptop)
 		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_LID);
-	}
-	if (backlight->priv->can_dim) {
+	if (backlight->priv->can_dim)
 		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_BACKLIGHT);
-	}
-	if (backlight->priv->can_sense) {
+	if (backlight->priv->can_sense)
 		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_AMBIENT);
-	}
 	g_object_unref (prefs_server);
 
 	/* watch for dim value changes */
-	backlight->priv->conf = gpm_conf_new ();
-	g_signal_connect (backlight->priv->conf, "value-changed",
-			  G_CALLBACK (conf_key_changed_cb), backlight);
+	backlight->priv->conf = gconf_client_get_default ();
 
-	/* get and set the default idle dim timeout */
-	gpm_conf_get_uint (backlight->priv->conf,
-			   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
-			   &backlight->priv->idle_dim_timeout);
-	gpm_conf_set_uint (backlight->priv->conf,
-			   GPM_CONF_GNOME_SS_PM_DELAY,
-			   backlight->priv->idle_dim_timeout);
+	/* watch gnome-power-manager keys */
+	gconf_client_add_dir (backlight->priv->conf, GPM_CONF_DIR, GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_notify_add (backlight->priv->conf, GPM_CONF_DIR,
+				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
+				 backlight, NULL, NULL);
 
 	/* set the main brightness, this is designed to be updated if the user changes the
 	 * brightness so we can undim to the 'correct' value */
-	gpm_conf_get_uint (backlight->priv->conf,
-			   GPM_CONF_BACKLIGHT_BRIGHTNESS_AC,
-			   &backlight->priv->master_percentage);
+	backlight->priv->master_percentage = gconf_client_get_int (backlight->priv->conf, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC, NULL);
 
 	/* watch for brightness up and down buttons and also check lid state */
 	backlight->priv->button = gpm_button_new ();
@@ -924,14 +875,15 @@ gpm_backlight_init (GpmBacklight *backlight)
 	g_signal_connect (backlight->priv->ac_adapter, "ac-adapter-changed",
 			  G_CALLBACK (ac_adapter_changed_cb), backlight);
 
+	/* watch for idle mode changes */
+	backlight->priv->idle = gpm_idle_new ();
+	g_signal_connect (backlight->priv->idle, "idle-changed",
+			  G_CALLBACK (idle_changed_cb), backlight);
+
 	/* assumption */
 	backlight->priv->system_is_idle = FALSE;
-	gpm_conf_get_uint (backlight->priv->conf,
-			   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
-			   &backlight->priv->idle_dim_timeout);
-	gpm_conf_set_uint (backlight->priv->conf,
-			   GPM_CONF_GNOME_SS_PM_DELAY,
-			   backlight->priv->idle_dim_timeout);
+	backlight->priv->idle_dim_timeout = gconf_client_get_int (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_TIME, NULL);
+	gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 
 	/* use a visual widget */
 	backlight->priv->feedback = gpm_feedback_new ();
@@ -950,11 +902,6 @@ gpm_backlight_init (GpmBacklight *backlight)
 				  G_CALLBACK (control_resume_cb), backlight);
 	}
 
-	/* watch for idle mode changes */
-	backlight->priv->idle = gpm_idle_new ();
-	g_signal_connect (backlight->priv->idle, "idle-changed",
-			  G_CALLBACK (idle_changed_cb), backlight);
-
 	/* sync at startup */
 	gpm_light_sensor_get_absolute (backlight->priv->light_sensor, &value);
 	backlight->priv->ambient_sensor_value = value / 100.0f;
