@@ -27,22 +27,24 @@
 
 #include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
+#include <errno.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
-#include <gst/gst.h>
 
 #include "gpm-stock-icons.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
-
 #include "gpm-manager.h"
-#include "dbus/xdg-power-management-core.h"
+#include "gpm-session.h"
 
-static void gpm_exit (GpmManager *manager);
+#include "org.freedesktop.PowerManagement.h"
+
+#include "egg-debug.h"
 
 /**
  * gpm_object_register:
@@ -99,16 +101,6 @@ gpm_object_register (DBusGConnection *connection,
 	return TRUE;
 }
 
-/**
- * gpm_exit:
- * @manager: This manager class instance
- **/
-static void
-gpm_exit (GpmManager *manager)
-{
-	exit (0);
-}
-
 /**
  * timed_exit_cb:
  * @loop: The main loop
@@ -131,23 +123,18 @@ int
 main (int argc, char *argv[])
 {
 	GMainLoop *loop;
-	GnomeClient *master;
-	GnomeClientFlags flags;
 	DBusGConnection *system_connection;
 	DBusGConnection *session_connection;
 	gboolean verbose = FALSE;
 	gboolean version = FALSE;
-	gboolean no_daemon = FALSE;
 	gboolean timed_exit = FALSE;
 	gboolean immediate_exit = FALSE;
+	GpmSession *session = NULL;
 	GpmManager *manager = NULL;
 	GError *error = NULL;
 	GOptionContext *context;
- 	GnomeProgram *program;
 
 	const GOptionEntry options[] = {
-		{ "no-daemon", '\0', 0, G_OPTION_ARG_NONE, &no_daemon,
-		  N_("Do not daemonize"), NULL },
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
 		  N_("Show extra debugging information"), NULL },
 		{ "version", '\0', 0, G_OPTION_ARG_NONE, &version,
@@ -159,50 +146,36 @@ main (int argc, char *argv[])
 		{ NULL}
 	};
 
-	context = g_option_context_new (N_("GNOME Power Manager"));
-
+	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	if (! g_thread_supported ())
+		g_thread_init (NULL);
+	dbus_g_thread_init ();
+	g_type_init ();
+
+	context = g_option_context_new (N_("GNOME Power Manager"));
+	/* TRANSLATORS: program name, a simple app to view pending updates */
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
-
-	program = gnome_program_init (argv[0], VERSION,
-			   	      LIBGNOMEUI_MODULE, argc, argv,
-			    	      GNOME_PROGRAM_STANDARD_PROPERTIES,
-			    	      GNOME_PARAM_GOPTION_CONTEXT, context,
-			    	      GNOME_PARAM_HUMAN_READABLE_NAME, GPM_NAME,
-			    	      NULL);
-	g_set_application_name (GPM_NAME);
-
-	master = gnome_master_client ();
-	flags = gnome_client_get_flags (master);
+	g_option_context_set_summary (context, _("GNOME Power Manager"));
+	g_option_context_parse (context, &argc, &argv, NULL);
+	g_option_context_free (context);
 
 	if (version) {
 		g_print ("Version %s\n", VERSION);
 		goto unref_program;
 	}
 
-	if (flags & GNOME_CLIENT_IS_CONNECTED) {
-		/* We'll disable this as users are getting constant crashes */
-		/* gnome_client_set_restart_style (master, GNOME_RESTART_IMMEDIATELY);*/
-		gnome_client_flush (master);
-	}
-
-	g_signal_connect (GTK_OBJECT (master), "die", G_CALLBACK (gpm_exit), manager);
-
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 	dbus_g_thread_init ();
 
+	gtk_init (&argc, &argv);
 	egg_debug_init (verbose);
 
-	/* we need to daemonize before we get a system connection to fix #366057 */
-	if (no_daemon == FALSE && daemon (0, 0)) {
-		egg_error ("Could not daemonize: %s", g_strerror (errno));
-	}
-
 	egg_debug ("GNOME %s %s", GPM_NAME, VERSION);
 
 	/* check dbus connections, exit if not valid */
@@ -226,12 +199,13 @@ main (int argc, char *argv[])
 			   "or gnome startup when you start a new session.");
 	}
 
-	/* Add application specific icons to search path */
+	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
-	/* initialise gstreamer */
-	gst_init (&argc, &argv);
+	/* we have to register with the session as we are starting up with the panel */
+	session = gpm_session_new ();
+	gpm_session_register_client (session, "gnome-power-manager", getenv ("DESKTOP_AUTOSTART_ID"));
 
 	/* create a new gui object */
 	manager = gpm_manager_new ();
@@ -246,7 +220,7 @@ main (int argc, char *argv[])
 	/* Only timeout and close the mainloop if we have specified it
 	 * on the command line */
 	if (timed_exit) {
-		g_timeout_add (1000 * 20, (GSourceFunc) timed_exit_cb, loop);
+		g_timeout_add_seconds (20, (GSourceFunc) timed_exit_cb, loop);
 	}
 
 	if (immediate_exit == FALSE) {
@@ -255,14 +229,9 @@ main (int argc, char *argv[])
 
 	g_main_loop_unref (loop);
 
-	/* rip down gstreamer */
-	gst_deinit ();
+	g_object_unref (session);
 	g_object_unref (manager);
 unref_program:
-	g_object_unref (program);
-/*
 	g_option_context_free (context);
-*/
-
 	return 0;
 }
