@@ -661,6 +661,155 @@ gpm_stats_update_info_data (const DkpDevice *device)
 	return;
 }
 
+/**
+ * gpm_stats_format_cmdline:
+ **/
+static gchar *
+gpm_stats_format_cmdline (const DkpWakeupsObj *obj)
+{
+	gchar *found;
+	gchar *temp = NULL;
+	gchar *cmdline;
+	const gchar *temp_ptr;
+
+	/* nothing */
+	if (obj->cmdline == NULL) {
+		/* TRANSLATORS: the command line was not provided */
+		temp_ptr = _("No data");
+		goto out;
+	}
+
+	/* common kernel cmd names */
+	if (strcmp (obj->cmdline, "insmod") == 0) {
+		/* TRANSLATORS: kernel module, usually a device driver */
+		temp_ptr = _("Kernel module");
+		goto out;
+	}
+	if (strcmp (obj->cmdline, "modprobe") == 0) {
+		/* TRANSLATORS: kernel module, usually a device driver */
+		temp_ptr = _("Kernel module");
+		goto out;
+	}
+	if (strcmp (obj->cmdline, "swapper") == 0) {
+		/* TRANSLATORS: kernel housekeeping */
+		temp_ptr = _("Kernel core");
+		goto out;
+	}
+	if (strcmp (obj->cmdline, "kernel-ipi") == 0) {
+		/* TRANSLATORS: interrupt between processors */
+		temp_ptr = _("Interprocessor interrupt");
+		goto out;
+	}
+	if (strcmp (obj->cmdline, "interrupt") == 0) {
+		/* TRANSLATORS: unknown interrupt */
+		temp_ptr = _("Interrupt");
+		goto out;
+	}
+
+	/* truncate at first space or ':' */
+	temp = g_strdup (obj->cmdline);
+	found = strstr (temp, ":");
+	if (found != NULL)
+		*found = '\0';
+	found = strstr (temp, " ");
+	if (found != NULL)
+		*found = '\0';
+
+	/* remove path */
+	found = g_strrstr (temp, "/");
+	if (found != NULL && strncmp (temp, "event", 5) != 0)
+		temp_ptr = found + 1;
+	else
+		temp_ptr = temp;
+
+out:
+	/* format command line */
+	if (obj->is_userspace)
+		cmdline = g_markup_escape_text (temp_ptr, -1);
+	else
+		cmdline = g_markup_printf_escaped ("<i>%s</i>", temp_ptr);
+	g_free (temp);
+
+	/* return */
+	return cmdline;
+}
+
+/**
+ * gpm_stats_format_details:
+ **/
+static gchar *
+gpm_stats_format_details (const DkpWakeupsObj *obj)
+{
+	gchar *details;
+
+	/* replace common driver names */
+	if (strcmp (obj->details, "i8042") == 0) {
+		/* TRANSLATORS: the keyboard and mouse device event */
+		details = g_strdup (_("PS/2 keyboard/mouse/touchpad"));
+	} else if (strcmp (obj->details, "acpi") == 0) {
+		/* TRANSLATORS: ACPI, the Intel power standard on laptops and desktops */
+		details = g_strdup (_("ACPI"));
+	} else if (strcmp (obj->details, "ata_piix") == 0) {
+		/* TRANSLATORS: serial ATA is a new style of hard disk interface */
+		details = g_strdup (_("Serial ATA"));
+	} else if (strcmp (obj->details, "libata") == 0) {
+		/* TRANSLATORS: this is the old-style ATA interface */
+		details = g_strdup (_("ATA host controller"));
+	} else if (strcmp (obj->details, "iwl3945") == 0 || strcmp (obj->details, "iwlagn") == 0) {
+		/* TRANSLATORS: 802.11 wireless adaptor */
+		details = g_strdup (_("Intel wireless adaptor"));
+
+	/* try to make the wakeup type nicer */
+	} else if (g_str_has_prefix (obj->details, "__mod_timer")) {
+		/* TRANSLATORS: a timer is something that fires periodically */
+		details = g_strdup_printf (_("Timer %s"), obj->details+12);
+	} else if (g_str_has_prefix (obj->details, "mod_timer")) {
+		/* TRANSLATORS: a timer is something that fires periodically */
+		details = g_strdup_printf (_("Timer %s"), obj->details+10);
+	} else if (g_str_has_prefix (obj->details, "hrtimer_start_expires")) {
+		/* TRANSLATORS: a timer is something that fires periodically */
+		details = g_strdup_printf (_("Timer %s"), obj->details+22);
+	} else if (g_str_has_prefix (obj->details, "hrtimer_start")) {
+		/* TRANSLATORS: a timer is something that fires periodically */
+		details = g_strdup_printf (_("Timer %s"), obj->details+14);
+	} else if (g_str_has_prefix (obj->details, "do_setitimer")) {
+		/* TRANSLATORS: a timer is something that fires periodically */
+		details = g_strdup_printf (_("Timer %s"), obj->details+10);
+	} else if (g_str_has_prefix (obj->details, "do_nanosleep")) {
+		/* TRANSLATORS: this is a task that's woken up from sleeping */
+		details = g_strdup_printf (_("Sleep %s"), obj->details+13);
+	} else if (g_str_has_prefix (obj->details, "enqueue_task_rt")) {
+		/* TRANSLATORS: this is a new realtime task */
+		details = g_strdup_printf (_("New task %s"), obj->details+16);
+	} else if (g_str_has_prefix (obj->details, "futex_wait")) {
+		/* TRANSLATORS: this is a task thats woken to check state */
+		details = g_strdup_printf (_("Wait %s"), obj->details+11);
+	} else if (g_str_has_prefix (obj->details, "queue_delayed_work_on")) {
+		/* TRANSLATORS: a work queue is a list of work that has to be done */
+		details = g_strdup_printf (_("Work queue %s"), obj->details+22);
+	} else if (g_str_has_prefix (obj->details, "queue_delayed_work")) {
+		/* TRANSLATORS: a work queue is a list of work that has to be done */
+		details = g_strdup_printf (_("Work queue %s"), obj->details+19);
+	} else if (g_str_has_prefix (obj->details, "dst_run_gc")) {
+		/* TRANSLATORS: this is when the networking subsystem clears out old entries */
+		details = g_strdup_printf (_("Network route flush %s"), obj->details+11);
+	} else if (g_str_has_prefix (obj->details, "usb_hcd_poll_rh_status")) {
+		/* TRANSLATORS: activity on the USB bus */
+		details = g_strdup_printf (_("USB activity %s"), obj->details+23);
+	} else if (g_str_has_prefix (obj->details, "schedule_hrtimeout_range")) {
+		/* TRANSLATORS: we've timed out of an aligned timer */
+		details = g_strdup_printf (_("Wakeup %s"), obj->details+25);
+	} else if (g_str_has_prefix (obj->details, "Local timer interrupts")) {
+		/* TRANSLATORS: interupts on the system required for basic operation */
+		details = g_strdup (_("Local interrupts"));
+	} else if (g_str_has_prefix (obj->details, "Rescheduling interrupts")) {
+		/* TRANSLATORS: interrupts when a task gets moved from one core to another */
+		details = g_strdup (_("Rescheduling interrupts"));
+	} else
+		details = g_markup_escape_text (obj->details, -1);
+
+	return details;
+}
 /**
  * gpm_stats_add_wakeups_obj:
  **/
@@ -669,12 +818,9 @@ gpm_stats_add_wakeups_obj (const DkpWakeupsObj *obj)
 {
 	const gchar *icon;
 	gchar *value;
-	gchar *cmdline;
 	gchar *id;
-	const gchar *cmdline_ptr;
-	gchar *cmdline_escaped;
 	gchar *details;
-	gchar *found;
+	gchar *cmdline;
 	GtkTreeIter iter;
 
 	if (obj->is_userspace) {
@@ -691,86 +837,18 @@ gpm_stats_add_wakeups_obj (const DkpWakeupsObj *obj)
 	/* formate value to one decimal place */
 	value = g_strdup_printf ("%.1f", obj->value);
 
-	/* truncate at first space or ':' */
-	cmdline = g_strdup (obj->cmdline);
-	found = strstr (cmdline, ":");
-	if (found != NULL)
-		*found = '\0';
-	found = strstr (cmdline, " ");
-	if (found != NULL)
-		*found = '\0';
-
-	/* remove ./ */
-	found = g_strrstr (cmdline, "/");
-	if (found != NULL)
-		cmdline_ptr = found + 1;
-	else
-		cmdline_ptr = cmdline;
-
-	if (strcmp (cmdline_ptr, "insmod") == 0)
-		cmdline_ptr = _("Kernel module");
-	else if (strcmp (cmdline_ptr, "modprobe") == 0)
-		cmdline_ptr = _("Kernel module");
-	else if (strcmp (cmdline_ptr, "swapper") == 0)
-		cmdline_ptr = _("Kernel core");
-	else if (strcmp (cmdline_ptr, "kernel-ipi") == 0)
-		cmdline_ptr = _("Interprocessor interrupt");
-	else if (strcmp (cmdline_ptr, "interrupt") == 0)
-		cmdline_ptr = _("Interrupt");
-
-	/* format command line */
-	if (obj->is_userspace)
-		cmdline_escaped = g_markup_escape_text (cmdline_ptr, -1);
-	else
-		cmdline_escaped = g_markup_printf_escaped ("<i>%s</i>", cmdline_ptr);
-
-	/* replace common driver names */
-	if (strcmp (obj->details, "i8042") == 0)
-		details = g_strdup (_("PS/2 keyboard/mouse/touchpad"));
-	else if (strcmp (obj->details, "acpi") == 0)
-		details = g_strdup (_("ACPI"));
-	else if (strcmp (obj->details, "ata_piix") == 0)
-		details = g_strdup (_("Serial ATA"));
-	else if (strcmp (obj->details, "libata") == 0)
-		details = g_strdup (_("ATA host controller"));
-	else if (strcmp (obj->details, "iwl3945") == 0)
-		details = g_strdup (_("Intel wireless adaptor"));
-
-	/* try to make the wakeup type nicer */
-	else if (g_str_has_prefix (obj->details, "__mod_timer"))
-		details = g_strdup_printf (_("Timer %s"), obj->details+12);
-	else if (g_str_has_prefix (obj->details, "mod_timer"))
-		details = g_strdup_printf (_("Timer %s"), obj->details+10);
-	else if (g_str_has_prefix (obj->details, "do_setitimer"))
-		details = g_strdup_printf (_("Timer %s"), obj->details+10);
-	else if (g_str_has_prefix (obj->details, "do_nanosleep"))
-		details = g_strdup_printf (_("Sleep %s"), obj->details+13);
-	else if (g_str_has_prefix (obj->details, "futex_wait"))
-		details = g_strdup_printf (_("Wait %s"), obj->details+11);
-	else if (g_str_has_prefix (obj->details, "queue_delayed_work_on"))
-		details = g_strdup_printf (_("Work queue %s"), obj->details+22);
-	else if (g_str_has_prefix (obj->details, "queue_delayed_work"))
-		details = g_strdup_printf (_("Work queue %s"), obj->details+19);
-	else if (g_str_has_prefix (obj->details, "dst_run_gc"))
-		details = g_strdup_printf (_("Network route flush %s"), obj->details+11);
-	else if (g_str_has_prefix (obj->details, "usb_hcd_poll_rh_status"))
-		details = g_strdup_printf (_("USB activity %s"), obj->details+23);
-	else if (g_str_has_prefix (obj->details, "Local timer interrupts"))
-		details = g_strdup (_("Local interrupts"));
-	else if (g_str_has_prefix (obj->details, "Rescheduling interrupts"))
-		details = g_strdup (_("Rescheduling interrupts"));
-	else
-		details = g_markup_escape_text (obj->details, -1);
+	/* get formatted lines */
+	cmdline = gpm_stats_format_cmdline (obj);
+	details = gpm_stats_format_details (obj);
 
 	gtk_list_store_append (list_store_wakeups, &iter);
 	gtk_list_store_set (list_store_wakeups, &iter,
 			    GPM_WAKEUPS_COLUMN_ID, id,
 			    GPM_WAKEUPS_COLUMN_VALUE, value,
-			    GPM_WAKEUPS_COLUMN_CMDLINE, cmdline_escaped,
+			    GPM_WAKEUPS_COLUMN_CMDLINE, cmdline,
 			    GPM_WAKEUPS_COLUMN_DETAILS, details,
 			    GPM_WAKEUPS_COLUMN_ICON, icon, -1);
 	g_free (cmdline);
-	g_free (cmdline_escaped);
 	g_free (details);
 	g_free (value);
 	g_free (id);
@@ -835,12 +913,17 @@ gpm_stats_set_title (GtkWindow *window, gint page_num)
 {
 	gchar *title;
 	const gchar * const page_titles[] = {
+		/* TRANSLATORS: shown on the titlebar */
 		N_("Device Information"),
+		/* TRANSLATORS: shown on the titlebar */
 		N_("Device History"),
+		/* TRANSLATORS: shown on the titlebar */
 		N_("Device Profile"),
+		/* TRANSLATORS: shown on the titlebar */
 		N_("Processor Wakeups")
 	};
 
+	/* TRANSLATORS: shown on the titlebar */
 	title = g_strdup_printf ("%s - %s", _("Power Statistics"), _(page_titles[page_num]));
 	gtk_window_set_title (window, title);
 	g_free (title);
@@ -1259,6 +1342,7 @@ main (int argc, char *argv[])
 
 	const GOptionEntry options[] = {
 		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
+		  /* TRANSLATORS: show verbose debugging */
 		  N_("Show extra debugging information"), NULL },
 		{ NULL}
 	};
@@ -1275,6 +1359,7 @@ main (int argc, char *argv[])
 	g_type_init ();
 
 	context = g_option_context_new (NULL);
+	/* TRANSLATORS: the program name */
 	g_option_context_set_summary (context, _("Power Statistics"));
 	g_option_context_add_main_entries (context, options, NULL);
 	g_option_context_parse (context, &argc, &argv, NULL);
@@ -1486,6 +1571,7 @@ main (int argc, char *argv[])
 		gtk_list_store_append (list_store_devices, &iter);
 		gtk_list_store_set (list_store_devices, &iter,
 				    GPM_DEVICES_COLUMN_ID, "wakeups",
+				    /* TRANSLATORS: the icon for the CPU */
 				    GPM_DEVICES_COLUMN_TEXT, _("Processor"),
 				    GPM_DEVICES_COLUMN_ICON, "computer", -1);
 	}
